[build] cmd/release: start using macOS 12 releaselets in Go 1.18 Beta 1

11 views
Skip to first unread message

Dmitri Shuralyov (Gerrit)

unread,
Dec 7, 2021, 7:08:26 PM12/7/21
to Dmitri Shuralyov, goph...@pubsubhelper.golang.org, golang-...@googlegroups.com, Heschi Kreinick, Gopher Robot, Carlos Amedee, Alex Rakoczy, golang-co...@googlegroups.com

Dmitri Shuralyov submitted this change.

View Change



1 is the latest approved patch-set.
No files were changed between the latest approved patch-set and the submitted one.

Approvals: Heschi Kreinick: Looks good to me, approved Dmitri Shuralyov: Trusted
cmd/release: start using macOS 12 releaselets in Go 1.18 Beta 1

The work to add macOS 12 builders for amd64 and arm64 was completed
ahead of Go 1.18 Beta 1, so we have the opportunity to pick between
starting to use them or stay with existing macOS 11 builders longer.

As part of go.dev/issue/40561 we discussed our available options and
opted to select macOS 12 releaselets for Go 1.18 on both architectures,
starting with first beta release. This CL implements that decision.

Tested:
I ran 'release -target=darwin-amd64 -version=go1.18beta123 -rev=HEAD'
locally and it completed successfully; all.bash release tests passed.

For golang/go#40561.

Change-Id: Ia80c4862a5137b5264c7a855452be25bddd79840
Reviewed-on: https://go-review.googlesource.com/c/build/+/369958
Trust: Dmitri Shuralyov <dmit...@golang.org>
Reviewed-by: Heschi Kreinick <hes...@google.com>
---
M cmd/release/release_test.go
M cmd/release/release.go
2 files changed, 39 insertions(+), 6 deletions(-)

diff --git a/cmd/release/release.go b/cmd/release/release.go
index 948edee..72f4e7c 100644
--- a/cmd/release/release.go
+++ b/cmd/release/release.go
@@ -218,14 +218,14 @@
Builder: "windows-arm64-10",
},
{
- GoQuery: ">= go1.17beta1",
+ GoQuery: ">= go1.18beta1", // Start exercising a macOS 12 releaselet as of Go 1.18 Beta 1; see issue 40561.
OS: "darwin",
Arch: "amd64",
Race: true,
- Builder: "darwin-amd64-11_0",
+ Builder: "darwin-amd64-12_0",
},
{
- GoQuery: ">= go1.18beta1", // Go 1.18 Beta 1 is still to be finalized as part of issue 40561, but macOS 12 for now.
+ GoQuery: ">= go1.18beta1", // Start exercising a macOS 12 releaselet as of Go 1.18 Beta 1; see issue 40561.
OS: "darwin",
Arch: "arm64",
Race: true,
@@ -263,6 +263,13 @@
Builder: "freebsd-amd64-11_2",
},
{
+ GoQuery: ">= go1.17beta1 && < go1.18beta1",
+ OS: "darwin",
+ Arch: "amd64",
+ Race: true,
+ Builder: "darwin-amd64-11_0",
+ },
+ {
GoQuery: "< go1.17beta1", // See golang/go#46161.
OS: "darwin",
Arch: "amd64",
diff --git a/cmd/release/release_test.go b/cmd/release/release_test.go
index 83134c8..dc3d26c 100644
--- a/cmd/release/release_test.go
+++ b/cmd/release/release_test.go
@@ -124,13 +124,13 @@
{"go1.16", "darwin-amd64", "darwin-amd64-10_15"},
// Go 1.17 uses MacOS 11.0.
{"go1.17", "darwin-amd64", "darwin-amd64-11_0"},
- // Go 1.18 uses MacOS 11.0.
- {"go1.18", "darwin-amd64", "darwin-amd64-11_0"},
+ // Go 1.18 starts using a macOS 12 releaselet.
+ {"go1.18", "darwin-amd64", "darwin-amd64-12_0"},
// macOS (arm64)
// Go 1.16 and 1.17 use macOS 11.
{"go1.16", "darwin-arm64", "darwin-arm64-11_0-toothrot"},
{"go1.17", "darwin-arm64", "darwin-arm64-11_0-toothrot"},
- // Go 1.18 starts using macOS 12 pending decision in issue 40561.
+ // Go 1.18 starts using a macOS 12 releaselet.
{"go1.18", "darwin-arm64", "darwin-arm64-12_0-toothrot"},

// Windows

To view, visit change 369958. To unsubscribe, or for help writing mail filters, visit settings.

Gerrit-Project: build
Gerrit-Branch: master
Gerrit-Change-Id: Ia80c4862a5137b5264c7a855452be25bddd79840
Gerrit-Change-Number: 369958
Gerrit-PatchSet: 3
Gerrit-Owner: Dmitri Shuralyov <dmit...@golang.org>
Gerrit-Reviewer: Dmitri Shuralyov <dmit...@golang.org>
Gerrit-Reviewer: Gopher Robot <go...@golang.org>
Gerrit-Reviewer: Heschi Kreinick <hes...@google.com>
Gerrit-CC: Alex Rakoczy <al...@golang.org>
Gerrit-CC: Carlos Amedee <car...@golang.org>
Gerrit-MessageType: merged
Reply all
Reply to author
Forward
0 new messages